"""
django-hilbert is one of many Django apps which is a loose collection of utility functions.
It is a mixture of Python code and Javascript that I find myself writing over and 
over. Primarily it focuses around utilities for AJAX and testing.
"""

__version__ = '0.4.2'
